@@ -376,7 +376,11 @@ class Main:
         self.dialog.withdraw()
         self.dialog.clear()
         if dat.type[0]=='S':
-            self.dialog.insert('end',dat.comment)
+            if len(dat.comment)==6:
+                for j in dat.comment:
+                    self.dialog.insert('end',j)
+            else:
+                self.dialog.insert('end',dat.comment)
         else:
             self.dialog.insert('end','No comments available')
         #update fluobox
