@@ -379,6 +379,13 @@ class ssrlascii:
         else:
             self.iF=ones((len(self.i0)),Float32)
             self.ICR=ones((len(self.i0)),Float32)
+        #check SHAPEs...
+        if self.iF.shape!=self.ICR.shape:
+            #presume 1 ICR and multiple FFs
+            temp=ones(self.iF.shape,Float)
+            for i in range(self.iF.shape[1]):
+                temp[:,i]=self.ICR[:,0]
+            self.ICR=temp
 
 ###################################
 ##
@@ -900,15 +907,71 @@ class nslsnewascii:
         for line in lines:
             if line !='':
                 parsed=split(line)
-                if readstate==1 and parsed[0][0] in digits:
+                if readstate==1: #header line...
+                    #parse header info
+                    if 'Ge1' in parsed:
+                        #multielement
+                        chandef=[[],[],[],[],[],[],[],[]]
+                        i=0
+                        for col in parsed:
+                            if col in ['Energy','ev','eV']: chandef[0].append(i)
+                            if col in ['Timer','Time','Clock']: chandef[1].append(i)
+                            if lower(col)=='i0': chandef[2].append(i)
+                            if lower(col)=='i1': chandef[3].append(i)
+                            if lower(col)=='i2': chandef[4].append(i)
+                            if lower(col)[0:2]=='ge':chandef[5].append(i)
+                            if len(col)>2 and lower(col)[0:3]=='icr':chandef[6].append(i)
+                            i+=1 
+                        readstate=3
+                    else:
+                        readstate=2
+                if readstate==2 and parsed[0][0] in digits:
                     #then we have a data line
                     self.rtc.append(1.0)
                     self.eV.append(atof(parsed[0]))
                     self.i0.append(atof(parsed[1]))
-                    self.i1.append(atof(parsed[2]))
+                    self.i1.append(atof(parsed[3]))
                     self.i2.append(atof(parsed[4]))
-                    self.iF.append(atof(parsed[3]))
-                    self.ICR.append(atof(parsed[3]))
+                    self.iF.append(atof(parsed[2]))
+                    self.ICR.append(atof(parsed[2]))
+                if readstate==3 and parsed[0][0] in digits:
+                    #then we have a data line for Ge multielements
+                    if chandef[1]!=[]:
+                        self.rtc.append(atof(parsed[chandef[1][0]]))
+                    else:
+                        self.rtc.append(1.0)
+                    if chandef[0]!=[]:
+                        self.eV.append(atof(parsed[chandef[0][0]]))
+                    else:
+                        self.eV.append(1.0)
+                    if chandef[2]!=[]:
+                        self.i0.append(atof(parsed[chandef[2][0]]))
+                    else:
+                        self.i0.append(1.0)
+                    if chandef[3]!=[]:
+                        self.i1.append(atof(parsed[chandef[3][0]]))
+                    else:
+                        self.i1.append(1.0)
+                    if chandef[4]!=[]:
+                        self.i2.append(atof(parsed[chandef[4][0]]))
+                    else:
+                        self.i2.append(1.0)
+                    if chandef[5]!=[]:
+                        spare=[]
+                        for sc in chandef[5]:
+                            spare.append(atof(parsed[sc]))
+                        self.iF.append(spare)
+                    else:
+                        self.iF.append(1.0)
+                    if chandef[6]!=[]:
+                        spare=[]
+                        for sc in chandef[6]:
+                            spare.append(atof(parsed[sc]))
+                        self.ICR.append(spare)
+                    else:
+                        self.ICR.append(1.0)                        
+                    
+                    
                 if parsed[0][0]=='-': readstate=1
         #convert all to arrays
         self.iF=array(self.iF)       
